﻿import es
import gamethread
import langlib
import playerlib
import popuplib

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"

popup = popuplib.create("sm_popup_vote_question")

common = langlib.Strings(lang_dir + "popup_common.ini")
messages = langlib.Strings(lang_dir + "vote/messages_vote.ini")
text = langlib.Strings(lang_dir + "vote/popup_vote.ini")

# ******************** Load ********************
def load():
	es.set("sm_vote_spam_protect", 0)

	create_popup()

# ******************** Events ********************
def es_map_start(event_var):
	delete_keygroup()

# ******************** Create popup ********************
def create_popup():
	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")
	popup.addline("Question?")
	popup.addline(" ")
	popup.addline("->1. %s" % (common("yes")))
	popup.addline("->2. %s" % (common("no")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	popup.select(1, choice)
	popup.select(2, choice)

	for i in range(3, 10):
		popup.submenu(i, "sm_popup_vote_question")

# ******************** Popup choice ********************
def choice(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("keygroup", "sm_keygroup_vote") == 1:
		if es.exists("key", "sm_keygroup_vote", player.steamid) == 1:
			if int(es.keygetvalue("sm_keygroup_vote", player.steamid, "voted")) == 0:
				es.keysetvalue("sm_keygroup_vote", player.steamid, "voted", 1)

				number = es.ServerVar("sm_vote_number")
				number += 1
				es.set("sm_vote_number", number)

				tokens["name"] = player.name

				if choice == 1:
					es.set("sm_vote_yes", es.ServerVar("sm_vote_yes") + 1)

					if es.ServerVar("sm_vote_show_votes_on") == 1:
						lang_msg("voted_yes", tokens)

				if choice == 2:
					es.set("sm_vote_no", es.ServerVar("sm_vote_no") + 1)

					if es.ServerVar("sm_vote_show_votes_on") == 1:
						lang_msg("voted_no", tokens)

				show_vote_time()

				if number >= es.ServerVar("sm_vote_players"):
					end_vote()
			else:
				es.tell(userid, "#green",  messages("already_voted", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("cant_vote", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_vote_active", tokens, player.get("lang")))

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def start():
	es.set("sm_vote_number", 0)
	es.set("sm_vote_yes", 0)
	es.set("sm_vote_no", 0)

	delete_keygroup()
	es.keygroupcreate("sm_keygroup_vote")

	popup.modline(3, es.ServerVar("sm_vote_question"))

	if es.ServerVar("sm_vote_all") == 1:
		number = create_key("#human")
	else:
		number = create_key("#human,#t")
		number += create_key("#human,#ct")

	es.set("sm_vote_players", number)

	if es.ServerVar("sm_vote_sounds_on") == 1:
		es.cexec_all("playgamesound", es.ServerVar("sm_vote_sound_start"))

	tokens = {}
	tokens["command"] = es.ServerVar("sm_vote_command")
	lang_msg("info", tokens)

	vote_time(es.ServerVar("sm_vote_length"))

def create_key(users):
	number = 0
	for ply in playerlib.getPlayerList(users):
		es.keycreate("sm_keygroup_vote", ply.steamid)
		es.keysetvalue("sm_keygroup_vote", ply.steamid, "voted", 0)
		popuplib.send("sm_popup_vote_question", ply.userid)
		number += 1
	return number

def vote_time(time):
	if es.exists("keygroup", "sm_keygroup_vote") == 1:
		minutes = int(time / 60)
		seconds = time - (minutes * 60)
		es.set("sm_vote_minutes", minutes)
		es.set("sm_vote_seconds", seconds)

		show_vote_time()

		if time > 0:
			gamethread.delayed(1, vote_time, (time - 1))
		else:
			end_vote()

def show_vote_time():
	vote_yes = es.ServerVar("sm_vote_yes")
	vote_no = es.ServerVar("sm_vote_no")
	players = es.ServerVar("sm_vote_players")
	minutes = es.ServerVar("sm_vote_minutes")
	seconds = es.ServerVar("sm_vote_seconds")
	number = es.ServerVar("sm_vote_number")

	es.set("sm_vote_yes_percentage", int(round(float(vote_yes) / float(players) * 100, 0)))

	tokens = {}
	for player in playerlib.getPlayerList("#human"):
		if seconds < 10:
			message = "%s:0%s | %s: %s/%s - %s: %s - %s: %s" % (minutes, seconds, messages("votes", tokens, player.get("lang")), number, players, messages("current", tokens, player.get("lang")), es.ServerVar("sm_vote_yes_percentage"), messages("needed", tokens, player.get("lang")), es.ServerVar("sm_vote_percentage"))
		else:
			message = "%s:%s | %s: %s/%s - %s: %s - %s: %s" % (minutes, seconds, messages("votes", tokens, player.get("lang")), number, players, messages("current", tokens, player.get("lang")), es.ServerVar("sm_vote_yes_percentage"), messages("needed", tokens, player.get("lang")), es.ServerVar("sm_vote_percentage"))
		es.server.queuecmd('usermsg hudhint %s "%s"' % (player.userid, message))

def end_vote():
	es.msg("#green", "Question: %s" % (es.ServerVar("sm_vote_question")))

	if int(es.ServerVar("sm_vote_yes_percentage")) < int(es.ServerVar("sm_vote_percentage")):
		es.msg("#green", "Answer: No.")
		#tokens = {}
		#lang_msg("not_enough", tokens)
	else:
		es.msg("#green", "Answer: Yes.")
		es.doblock(es.ServerVar("sm_vote_block"))

	es.set("sm_vote_spam_protect", 1)
	gamethread.delayed(es.ServerVar("sm_vote_delay"), es.set, ("sm_vote_spam_protect", 0))

	delete_keygroup()

def delete_keygroup():
	if es.exists("keygroup", "sm_keygroup_vote") == 1:
		es.keygroupdelete("sm_keygroup_vote")

# ******************** Unload ********************
def unload():
	delete_keygroup()

	popuplib.delete("sm_popup_vote_question")